

// This program is for part (e) of homework #(permanent version)

// Note: y_ records the simulated endogenous variables in alphabetical order
// ys0_ records the initial steady state
// ys_ records the terminal steady state
// We check that these line up at the end points
// Note: y_ has ys0_ in first column, ys_ in last column, explaining why it is 102 long; 
// The sample of size 100 is in between.

// Warning:  we align c, k, and the taxes to exploit the dynare syntax. See comments below. 
// So k in the program corresponds to k_{t+1} and the same timing holds for the taxes.

//Declares the endogenous variables;
var c k n;
//declares the exogenous variables // investment tax credit, consumption tax, capital tax, government spending
varexo taui tauc tauk g; 

parameters bet gam mu del alpha A gbar tauibar taucbar taukbar;

bet=.95;  // discount factor
gam=2;    // CRRA parameter
mu=0.4;    // allocation between consumption and leisure
del=.2;  //  depreciation rate
alpha=.33; //  capital's share
A=1;    // productivity
gbar=0.2;
tauibar=0;
taucbar=0;
taukbar=0;


//Alignment convention:
// g tauc taui tauk are now columns of ex_. Because of a bad design decision
// the date of ex_(1,:) doesn't necessarily match the date in y_. Whether they match depends
// on the number of lag periods in endogenous versus exogenous variables.
// In this example they match because tauc(-1) and taui(-1) enter the model.

// These decisions and the timing conventions mean that 
// y_(:,1) records the initial steady state, while y_(:,102) records the terminal steady state values.
// For j > 2, y_(:,j) records [c(j-1) .. k(j-1) ..   G(j-1)]  where k(j-1) means 
// end of period capital in period j-1, which equals k(j) in chapter 11 notation.
// Note that the jump in G occurs in y_(;,11), which confirms this timing.  
// the jump occurs now in ex_(11,1)

model;
// Resource Constraint
k=A*k(-1)^(alpha)*n^(1-alpha)+(1-del)*k(-1)-c-g;
// Intratemporal Equation
((c^(mu))*((1-n)^(1-mu)))^(-gam)*(mu*(c^(mu-1))*((1-n)^(1-mu)))=((1+tauc)/((1+tauc(+1))*(1-taui)))*bet*((c(+1)^(mu))*((1-n(+1))^(1-mu)))^(-gam)*(mu*(c(+1)^(mu-1))*
(1-n(+1))^(1-mu))*((1-taui(+1))*(1-del)+(1-tauk(+1))*A*alpha*k^(alpha-1)*n(+1)^(1-alpha));
//Intertemporal Equation.
(((1-mu)*c)/(mu*(1-n)))=((1-alpha)*A*(k(-1)^(alpha))*(n^(-alpha)))/(1+tauc);
end;

//Intial value 
initval;
k=  0.511661;
c= 1.24057;
n= 0.832621;
g = gbar;
tauc = taucbar;
taui = tauibar;
tauk = taukbar;
end;



steady;


gbar=0.4;
endval; // The following values determine the new steady state after the shocks.
k=  0.511661;
c= 1.24057;
n= 0.832621;
g =gbar;
tauc =taucbar;
taui =tauibar;
tauk =taukbar;
end;



steady;

//  The following lines produce a temporal increase in g at t=10
shocks;
var g;
periods 1:9;
values 0.2;
end;

// now solve the model
simul(periods=100);

co= ys0_(var_index('c'));
ko=ys0_(var_index('k'));
no=ys0_(var_index('n'));

ce= ys_(var_index('c'));
ke=ys_(var_index('k'));
ne=ys_(var_index('n'));

c_t= y_(var_index('c'),:);
k_t=y_(var_index('k'),:);
n_t=y_(var_index('n'),:);

c_t(1)-co
k_t(1)-ko
n_t(1)-no
c_t(102)-ce
k_t(102)-ke
n_t(102)-ne
//now calcurate the prices (and output)
r=alpha.*A.*((k_t(1:100))./n_t(2:101)).^(alpha -1);
w=(1-alpha).*A.*((k_t(1:100))./n_t(2:101)).^(alpha );
R=( ( (c_t(2:101).^mu).*(1-n_t(2:101).^(1-mu))   ).^(-gam).*mu.*(c_t(2:101)/(1-n_t(2:101)) )^(mu-1) )./ ...
(bet.*( ( (c_t(3:102).^mu).*(1-n_t(3:102).^(1-mu))   ).^(-gam).*mu.*(c_t(3:102)/(1-n_t(3:102)) )^(mu-1)));
y=A.*((k_t(1:100)).^alpha).*((n_t(2:101).^(1-alpha)));

// prices (and output) of initial steady 

ro=alpha.*A.*((ko)./no).^(alpha -1);
wo=(1-alpha).*A.*((ko)./no).^(alpha );
Ro=( ( (co.^mu).*(1-no.^(1-mu))   ).^(-gam).*mu.*(co/(1-no) )^(mu-1) )./ ...
(bet.*( ( (co.^mu).*(1-no.^(1-mu))   ).^(-gam).*mu.*(co/(1-no) )^(mu-1)));
yo=A.*((ko).^alpha).*((no.^(1-alpha)));
mul=(y(10)-yo)/0.2   //goverment purchases multiplier(defined in solution for hw1) 

//plot part
subplot(2,4,1)
plot([(k_t(1:100))' ko*ones(100,1)])
title('k')
subplot(2,4,2)
plot([(c_t(2:101))' co*ones(100,1)])
title('c')
subplot(2,4,3)
plot([(n_t(2:101))' no*ones(100,1)])
title('n')
subplot(2,4,4)
plot([(k_t(1:100)./n_t(2:101))' (ko/no)*ones(100,1)])
title('k/n')
subplot(2,4,5)
plot([(r)' ro*ones(100,1)])
title('r/q')
subplot(2,4,6)
plot([(w)' wo*ones(100,1)])
title('w/q')
subplot(2,4,7)
plot([(R)' Ro*ones(100,1)])
title('R')
subplot(2,4,8)
plot([(y)' yo*ones(100,1)])
title('y')
